@@ -84,7 +84,7 @@ setClass("Organism",
 #' @param setExInf Enable if all lower bounds of exchange reaction which are set to zero (i.e. no uptake possible!) should be set to -infitity
 #' @param ... Arguments of \code{\link{Organism-class}}
 #' @return Object of class Organism
-Organism <- function(model, algo="fba", ex="EX_", ex_comp=NA, csuffix="\\[c\\]", esuffix="\\[e\\]", lyse=F, feat=list(), 
+Organism <- function(model, algo="fba", ex="EX_", ex_comp=NA, csuffix="\\[c\\]", esuffix="\\[e\\]", lyse=FALSE, feat=list(), 
                      typename=NA, setExInf=TRUE, ...){
   if(is.na(typename)) typename <- sybil::mod_desc(model)
   rxname = sybil::react_id(model)
@@ -271,6 +271,7 @@ setMethod("optimizeLP", "Organism", function(object, lpob=object@lpobj, lb=objec
          lpSolveAPI = {solve_ok <- fbasl$stat==0},
          sybilGUROBI = {solve_ok <- fbasl$stat==2},
          stop("Solver not suported!"))
+  if(is.na(solve_ok)){solve_ok = FALSE}
   if(!solve_ok | fbasl$obj<cutoff){fbasl$obj <- 0}
   if(sec_obj!="none" && fbasl$obj!=0){
     switch(sec_obj,
